ContentComposer<T> class

ContentComposer sınıfı, kullanıcının metin girmesine ve içeriği belirlenen formatta (T) oluşturup göndermesine olanak tanır.

Genel olarak mesaj gönderme veya yorum ekleme gibi senaryolar için uygundur.

Kullanım Örneği:

ContentComposer<Message>(
  content: (text) => Message(content: text, sender: "User"),
  onSend: (message) => chatService.sendMessage(message),
  hintText: "Mesajınızı yazın...",
)

Burada content fonksiyonu, girilen metni Message modeline çeviriyor. onSend fonksiyonu ise mesajı göndermek için bir işlem yapıyor.

Inheritance

Constructors

ContentComposer({Key? key, TextEditingController? contentController, required T content(String), required void onSend(T), required String hintText})
ContentComposer widget'ı oluşturur.
const

Properties

content → T Function(String)
Girilen metni (String) belirlenen türde (T) bir nesneye çeviren fonksiyon.
final
contentController TextEditingController?
Metin giriş alanı için kullanılacak TextEditingController.
final
hashCode int
The hash code for this object.
no setterinherited
hintText String
Kullanıcıya gösterilecek "ipucu metni".
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSend → void Function(T)
Oluşturulan içeriği (T) işleyip gönderen fonksiyon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited